You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by cz...@apache.org on 2019/10/28 10:53:55 UTC

[sling-org-apache-sling-feature-analyser] branch master updated: Ignore org.xml. packages as well

This is an automated email from the ASF dual-hosted git repository.

cziegeler pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-feature-analyser.git


The following commit(s) were added to refs/heads/master by this push:
     new 28aaa49  Ignore org.xml. packages as well
28aaa49 is described below

commit 28aaa493cbb0f48a61995219f466d32bd7ffb573
Author: Carsten Ziegeler <cz...@apache.org>
AuthorDate: Mon Oct 28 11:53:45 2019 +0100

    Ignore org.xml. packages as well
---
 .../sling/feature/analyser/task/impl/CheckBundleExportsImports.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/main/java/org/apache/sling/feature/analyser/task/impl/CheckBundleExportsImports.java b/src/main/java/org/apache/sling/feature/analyser/task/impl/CheckBundleExportsImports.java
index baa2100..37ecafa 100644
--- a/src/main/java/org/apache/sling/feature/analyser/task/impl/CheckBundleExportsImports.java
+++ b/src/main/java/org/apache/sling/feature/analyser/task/impl/CheckBundleExportsImports.java
@@ -85,9 +85,9 @@ public class CheckBundleExportsImports implements AnalyserTask {
             if ( info.getImportedPackages() != null ) {
                 for(final PackageInfo i : info.getImportedPackages()) {
                     if ( i.getVersion() == null ) {
                         // don't report for javax and org.w3c. packages (TODO)
                         if ( !i.getName().startsWith("javax.")
-                             && !i.getName().startsWith("org.w3c.")) {
+                                && !i.getName().startsWith("org.w3c.") && !i.getName().startsWith("org.xml.")) {
                             getReport(reports, info).importWithoutVersion.add(i);
                         }
                     }
@@ -85,9 +85,9 @@ public class CheckBundleExportsImports implements AnalyserTask {
                 for(final PackageInfo i : info.getImportedPackages()) {
                     if ( i.getVersion() == null ) {
-                        // don't report for javax and org.w3c. packages (TODO)
+                        // don't report for javax, org.w3c. and org.xml. packages (TODO)
                         if ( !i.getName().startsWith("javax.")